@@ -242,30 +242,42 @@ namespace exactextract {
     public:
         // Construct a view of a raster r at an extent ex that is larger
         // and/or of finer resolution than r
-        RasterView(const AbstractRaster<T> & r, Grid<bounded_extent> ex) : AbstractRaster<T>(ex), m_raster{r} {
-            double disaggregation_factor_x = r.xres() / ex.dx();
-            double disaggregation_factor_y = r.yres() / ex.dy();
+        RasterView(const AbstractRaster<T> & r, Grid<bounded_extent> ex) :
+            AbstractRaster<T>(ex),
+                    m_raster{r},
+                    m_x_off{0},
+                    m_y_off{0},
+                    m_rx{1},
+                    m_ry{1} {
+            if (!this->grid().empty()) {
+                double disaggregation_factor_x = r.xres() / ex.dx();
+                double disaggregation_factor_y = r.yres() / ex.dy();
 
-            if (std::abs(disaggregation_factor_x - std::floor(disaggregation_factor_x)) > 1e-6 ||
-                std::abs(disaggregation_factor_y - std::floor(disaggregation_factor_y)) > 1e-6) {
-                throw std::runtime_error("Must construct view at resolution that is an integer multiple of original.");
+                if (std::abs(disaggregation_factor_x - std::floor(disaggregation_factor_x)) > 1e-6 ||
+                    std::abs(disaggregation_factor_y - std::floor(disaggregation_factor_y)) > 1e-6) {
+                    throw std::runtime_error("Must construct view at resolution that is an integer multiple of original.");
+                }
+
+                if (disaggregation_factor_x < 0 || disaggregation_factor_y < 0) {
+                    throw std::runtime_error("Must construct view at equal or higher resolution than original.");
+                }
+
+                m_x_off = static_cast<long>(std::round((ex.xmin() - r.xmin()) / ex.dx()));
+                m_y_off = static_cast<long>(std::round((r.ymax() - ex.ymax()) / ex.dy()));
+                m_rx = static_cast<size_t>(disaggregation_factor_x);
+                m_ry = static_cast<size_t>(disaggregation_factor_y);
             }
 
-            if (disaggregation_factor_x < 0 || disaggregation_factor_y < 0) {
-                throw std::runtime_error("Must construct view at equal or higher resolution than original.");
-            }
-
-            m_x_off = static_cast<long>(std::round((ex.xmin() - r.xmin()) / ex.dx()));
-            m_y_off = static_cast<long>(std::round((r.ymax() - ex.ymax()) / ex.dy()));
-            m_rx = static_cast<size_t>(disaggregation_factor_x);
-            m_ry = static_cast<size_t>(disaggregation_factor_y);
-
             if (r.has_nodata()) {
                 this->set_nodata(r.nodata());
             }
         }
 
         T operator()(size_t row, size_t col) const override {
+            if (m_raster.grid().empty()) {
+                return this->nodata();
+            }
+
             if (m_x_off < 0 && static_cast<size_t>(-m_x_off) > col) {
                 return this->nodata();
             }
